import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max, format  } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {top: 50, right:50, bottom:70, left: 100};
const xAxisLabelOffset = 50;


const App = () => {
  
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
    
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  const yValue = d => d.Zona;
  const xValue = d => d.Month;
  
	const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G','B')

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
  	.paddingInner(0.2);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  console.log("X Scale Ticks:", xScale.ticks(5));
    console.log("Y Scale Ticks:", yScale.domain());
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom 
          xScale={xScale} 
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          />
        <AxisLeft yScale={yScale} />
        <text className="axis-label" x={innerWidth / 2} y={innerHeight + xAxisLabelOffset} textAnchor="middle">Residuos Decultivos Generados</text>
        <Marks 
          data={data} 
          xScale={xScale} 
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          />
      </g>
    </svg>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);